@@ -339,11 +339,8 @@ int pth_event_occurred(pth_event_t ev)
 /* walk to next or previous event in an event ring */
 pth_event_t pth_event_walk(pth_event_t ev, unsigned int direction)
 {
-    pth_event_t evC;
-
     if (ev == NULL)
         return_errno(NULL, EINVAL);
-    evC = ev;
     do {
         if (direction & PTH_WALK_NEXT)
             ev = ev->ev_next;
