@@ -66,7 +66,7 @@ int pth_init(void)
     pth_attr_set(t_attr, PTH_ATTR_NAME,         "**SCHEDULER**");
     pth_attr_set(t_attr, PTH_ATTR_JOINABLE,     FALSE);
     pth_attr_set(t_attr, PTH_ATTR_CANCEL_STATE, PTH_CANCEL_DISABLE);
-    pth_attr_set(t_attr, PTH_ATTR_STACK_SIZE,   32*1024);
+    pth_attr_set(t_attr, PTH_ATTR_STACK_SIZE,   64*1024);
     pth_attr_set(t_attr, PTH_ATTR_STACK_ADDR,   NULL);
     pth_sched = pth_spawn(t_attr, pth_scheduler, NULL);
     if (pth_sched == NULL) {
@@ -185,7 +185,7 @@ static void pth_spawn_trampoline(void)
 pth_t pth_spawn(pth_attr_t attr, void *(*func)(void *), void *arg)
 {
     pth_t t;
-    int stacksize;
+    unsigned int stacksize;
     void *stackaddr;
     pth_time_t ts;
 
@@ -200,7 +200,7 @@ pth_t pth_spawn(pth_attr_t attr, void *(*func)(void *), void *arg)
         func = NULL;
 
     /* allocate a new thread control block */
-    stacksize = (attr == PTH_ATTR_DEFAULT ? 32*1024 : attr->a_stacksize);
+    stacksize = (attr == PTH_ATTR_DEFAULT ? 64*1024 : attr->a_stacksize);
     stackaddr = (attr == PTH_ATTR_DEFAULT ? NULL : attr->a_stackaddr);
     if ((t = pth_tcb_alloc(stacksize, stackaddr)) == NULL)
         return NULL; /* errno is inherited */
@@ -438,21 +438,24 @@ int pth_join(pth_t tid, void **value)
 /* delegates control back to scheduler for context switches */
 int pth_yield(pth_t to)
 {
+    pth_pqueue_t *q = NULL;
+
     pth_debug2("pth_yield: enter from thread \"%s\"", pth_current->name);
 
-    /* a given thread has to be ready or we ignore the request */
+    /* a given thread has to be new or ready or we ignore the request */
     if (to != NULL) {
-        if (to->state != PTH_STATE_READY)
-            to = NULL;
-        else if (!pth_pqueue_contains(&pth_RQ, to))
-            to = NULL;
-        if (to == NULL)
+        switch (to->state) {
+            case PTH_STATE_NEW:    q = &pth_NQ; break;
+            case PTH_STATE_READY:  q = &pth_RQ; break;
+            default:               q = NULL;
+        }
+        if (q == NULL || !pth_pqueue_contains(q, to))
             return_errno(FALSE, EINVAL);
     }
 
-    /* give a favored thread maximum priority in ready queue */
-    if (to != NULL)
-        pth_pqueue_favorite(&pth_RQ, to);
+    /* give a favored thread maximum priority in his queue */
+    if (to != NULL && q != NULL)
+        pth_pqueue_favorite(q, to);
 
     /* switch to scheduler */
     if (to != NULL)
